--------
REST API
--------

The same JupyterLab Server API spec, as found here, is available in an interactive form
`here (on swagger's petstore) <http://petstore.swagger.io/?url=https://raw.githubusercontent.com/jupyterlab/jupyterlab_server/master/jupyterlab_server/rest-api.yml#!/default>`__.
The `OpenAPI Initiative`_ (fka Swagger™) is a project used to describe
and document RESTful APIs.

.. openapi:: ../../../jupyterlab_server/rest-api.yml
    :examples:


.. _OpenAPI Initiative: https://www.openapis.org/
